summaryrefslogtreecommitdiffstats
path: root/kjumpingcube/kcubewidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjumpingcube/kcubewidget.cpp')
-rw-r--r--kjumpingcube/kcubewidget.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kjumpingcube/kcubewidget.cpp b/kjumpingcube/kcubewidget.cpp
index 27797683..d4556eac 100644
--- a/kjumpingcube/kcubewidget.cpp
+++ b/kjumpingcube/kcubewidget.cpp
@@ -73,9 +73,9 @@ TQPalette KCubeWidget::color(Owner forWhom)
** public functions **
** ****************************************************** */
-KCubeWidget::KCubeWidget(TQWidget* parent,const char* name
+KCubeWidget::KCubeWidget(TQWidget* tqparent,const char* name
,Owner owner,int value,int max)
- : TQFrame(parent,name),
+ : TQFrame(tqparent,name),
Cube(owner,value,max)
{
setFrameStyle(Panel|Raised);
@@ -85,7 +85,7 @@ KCubeWidget::KCubeWidget(TQWidget* parent,const char* name
setCoordinates(0,0);
//initialize hintTimer
// will be automatically destroyed by the parent
hintTimer = new TQTimer(this);
hintCounter=0;
connect(hintTimer,TQT_SIGNAL(timeout()),TQT_SLOT(hint()));
@@ -93,7 +93,7 @@ KCubeWidget::KCubeWidget(TQWidget* parent,const char* name
setPalette(kapp->palette());
// show values
- repaint(false);
+ tqrepaint(false);
}
KCubeWidget::~KCubeWidget()
@@ -240,7 +240,7 @@ void KCubeWidget::mouseReleaseEvent(TQMouseEvent *e)
if(e->x()< 0 || e->x() > width() || e->y() < 0 || e->y() > height())
return;
- if(e->button() == LeftButton && _clicksAllowed)
+ if(e->button() == Qt::LeftButton && _clicksAllowed)
{
stopHint();
emit clicked(row(),column(),true);
@@ -85,7 +85,7 @@ KCubeWidget::KCubeWidget(TQWidget* parent,const char* name
setCoordinates(0,0);
//initialize hintTimer
- // will be automatically destroyed by the parent
+ // will be automatically destroyed by the tqparent
hintTimer = new TQTimer(this);
hintCounter=0;